@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 21 May 2012                                              }
+{ last modified: 29 May 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -156,6 +156,7 @@ void MainWindow::initGUI()
     menuFile = new QMenu(this);
     menuFile->addAction(tr("Play this file next"), this, SLOT(onMenuFileSetNextClick()));
     menuFile->addAction(tr("Add this file to queue"), this, SLOT(onMenuFileAddQueueClick()));
+    menuFile->addAction(tr("Delete this file"), this, SLOT(onMenuFileRemoveClick()));
 
     updateEqualizerActionLabel();
     updateTimerActionLabel();
@@ -511,7 +512,7 @@ void MainWindow::play(const QString &filename, bool doCloseCurrent)
 
     QFileInfo info(filename);
     QString currDir = fs->getCurrentDirectory();
-    QString targetDir = info.absoluteDir().canonicalPath();
+    QString targetDir = info.absoluteDir().path();
     fs->cd(targetDir);
     fs->getCurrentFilesFull(playlist);
     fs->cd(currDir);
@@ -827,32 +828,13 @@ void MainWindow::onTitleChange()
         cur.setNum(currentFileIndex+1);
         tot.setNum(playlist.size());
         QFileInfo info(getCurrentFilename());
-        QString path = info.canonicalPath();
+        QString path = QDir::cleanPath(info.absolutePath());
         int n = path.lastIndexOf("/");
         path.remove(0, n+1);
         int w = width() - 50; // guessing notification popup space width, allowed for text
         QString s = cur+"/"+tot+" - ["+path+"]";
         QStringList dirLines = wordwrap(s, w, *notificationMetrics);
         QStringList titleLines = wordwrap(title, w, *notificationMetrics);
-        /*
-        if(titleLines.size() > 2)
-        {
-            do{
-                titleLines.removeLast();
-            }while(titleLines.size() > 2);
-            titleLines[1].chop(5);
-            titleLines[1].append("...");
-        }
-        int maxDirLines = 3 - titleLines.size();
-        if(dirLines.size() > maxDirLines)
-        {
-            do{
-                dirLines.removeLast();
-            }while(dirLines.size() > maxDirLines);
-            dirLines[1].chop(10);
-            dirLines[1].append("...]");
-        }
-        */
         s = dirLines.join("\n")+"\n"+titleLines.join("\n");
         showNotification(s);
     }
@@ -1012,6 +994,66 @@ void MainWindow::onMenuFileAddQueueClick()
         cacheNext();
 }
 
+void MainWindow::onMenuFileRemoveClick()
+{
+    QString filename = contextMenuOwner->getString();
+
+    QFileInfo info(filename);
+
+    QString msg;
+    msg.append(tr("filename")+": "+info.fileName()+"\n");
+    msg.append(tr("location")+": "+info.path());
+
+    QMessageBox::StandardButton result = QMessageBox::question(
+                this,
+                tr("Delete the file?"),
+                msg,
+                QMessageBox::Yes | QMessageBox::No,
+                QMessageBox::No);
+    if(result == QMessageBox::Yes)
+    {
+        bool isCurrent = (filename == getCurrentFilename());
+        bool wasPlaying = (player->getState() == pp_state_Playing);
+        if(isCurrent)
+            stop();
+        player->clearCache(filename);
+        // in Linux, there is no need to wait until the file is released
+        if(!fs->removeFile(filename))
+        {
+            QMessageBox::critical(
+                        this,
+                        tr("Cannot delete the file"),
+                        msg);
+            return;
+        }
+        showNotification(tr("The file has been deleted"));
+        queue.removeAll(filename);
+        playlist.removeOne(filename);
+        straightPlaylist.removeOne(filename);
+        if(isCurrent && (currentFileIndex >= 0))
+        {
+            if(wasPlaying)
+                currentFileIndex--;
+            else
+                currentFileIndex = -1;
+        }
+        if(
+            isCurrent && wasPlaying &&
+            (
+                !queue.isEmpty()
+                    ||
+                (OPTIONS.playMode != pmo_trackOnce) && (OPTIONS.playMode != pmo_trackLoop)
+            )
+        )
+        {
+            if(!runNext())
+                showStopNotification();
+        }
+        emit onFileDelete(filename);
+        QTimer::singleShot(0, this, SLOT(updateView()));
+    }
+}
+
 void MainWindow::onHeadsetStatusChange(bool isConnected)
 {
     if(checkResumeOnHangup)
@@ -1199,6 +1241,9 @@ bool MainWindow::runNext(bool doCloseCurrent)
         return true;
     }
 
+    if(playlist.isEmpty())
+        return false;
+
     int i;
     switch(OPTIONS.playMode)
     {
@@ -1331,6 +1376,11 @@ void MainWindow::doCacheNext()
     player->cache(cacheFilename);
 }
 
+void MainWindow::updateView()
+{
+    cd(fs->getCurrentDirectory());
+}
+
 void MainWindow::showStopTimerNotification()
 {
     showNotification(tr("Timer has been stopped"));
