@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 19 May 2012                                              }
+{ last modified: 29 May 2012                                              }
 {*************************************************************************/
 
 #ifndef MAINWINDOW_H
@@ -175,6 +175,7 @@ protected slots:
     void onMenuFolderAllAddClick();
     void onMenuFileSetNextClick();
     void onMenuFileAddQueueClick();
+    void onMenuFileRemoveClick();
 
     void onHeadsetStatusChange(bool isConnected);
     void onCallStart();
@@ -185,9 +186,11 @@ protected slots:
 
     void jumpToCurrentItem();
     void doCacheNext();
+    void updateView();
 
 signals:
     void onResize(const QSize& sz);
+    void onFileDelete(const QString& filename);
 
 private:
     static MainWindow* instance;
