@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 21 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #include "optionitem.h"
@@ -286,30 +286,8 @@ void OptionItem::click()
 
 void OptionItem::setRawLabelText(const QString &newText)
 {
-    QStringList words = newText.split(" ", QString::SkipEmptyParts);
-    QStringList lines;
-    QString line;
-    QString tmpLine;
-    QString wordSpaced;
-    QFontMetrics metrics = fontMetrics();
-    int maxWidth = width() - iconSize().width();
-    foreach(QString word, words)
-    {
-        wordSpaced = word + " ";
-        tmpLine = line + wordSpaced;
-        if(metrics.width(tmpLine) > maxWidth)
-        {
-            lines.append(line);
-            line = wordSpaced;
-        }
-        else
-        {
-            line = tmpLine;
-        }
-    }
-    if(!line.trimmed().isEmpty())
-        lines.append(line);
-    line = lines.join("\n");
+    QStringList lines = wordwrap(newText, width() - iconSize().width(), fontMetrics());
+    QString line = lines.join("\n");
     setText(line);
 }
 
