@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 28 May 2012                                              }
+{ last modified: 29 May 2012                                              }
 {*************************************************************************/
 
 #include "searchwindow.h"
@@ -34,6 +34,7 @@ SearchWindow::SearchWindow(QWidget *parent) :
     fs = MAINWINDOW->getFSMan();
     connect(fs, SIGNAL(onSearchFinished()), SLOT(onSearchFinished()));
     connect(fs, SIGNAL(onSearchResult(bool,QString,QString)), SLOT(onSearchResult(bool,QString,QString)));
+    connect(MAINWINDOW, SIGNAL(onFileDelete(QString)), SLOT(onFileDelete(QString)));
     if(fs->isUsingCache() && false)
     {
         isRealSearch = false;
@@ -45,6 +46,7 @@ SearchWindow::SearchWindow(QWidget *parent) :
     }
     lastCursorPos = 0;
     skipEnterPress = false;
+    itemToDelete = NULL;
 }
 
 SearchWindow::~SearchWindow()
@@ -85,6 +87,7 @@ void SearchWindow::deinitGui()
 {
     delete btnGo;
     delete editExp;
+    delete lblNotFound;
     ContainerDialog::deinitGui();
 }
 
@@ -199,6 +202,7 @@ void SearchWindow::onItemUp(QWidget *item, bool isClicked)
 void SearchWindow::onContextMenuShow(QWidget *item, QContextMenuEvent *event)
 {
     MAINWINDOW->onContextMenuShow(item, event);
+    setFocusToEdit();
 }
 
 void SearchWindow::onBtnGoClick()
@@ -240,3 +244,31 @@ void SearchWindow::onReturnPressed()
         onBtnGoClick();
     }
 }
+
+void SearchWindow::onFileDelete(const QString &filename)
+{
+    KineticListItem* item;
+    foreach(QObject* child, itemsContainer->children())
+    {
+        item = qobject_cast<KineticListItem*>(child);
+        if(!item)
+            continue;
+        if(item->getString() == filename)
+        {
+            itemToDelete = item;
+            QTimer::singleShot(0, this, SLOT(onDeletePendingItem()));
+            return;
+        }
+    }
+}
+
+void SearchWindow::onDeletePendingItem()
+{
+    if(itemToDelete)
+    {
+        delete itemToDelete;
+        itemsContainer->repositionChildrenV(ITEM_HEIGHT);
+        itemToDelete = NULL;
+        lblNotFound->setVisible(itemsContainer->children().isEmpty() && !editExp->text().isEmpty());
+    }
+}
