@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 28 May 2012                                              }
+{ last modified: 29 May 2012                                              }
 {*************************************************************************/
 
 #ifndef SEARCHWINDOW_H
@@ -49,6 +49,8 @@ protected:
     int lastCursorPos;
     bool skipEnterPress;
 
+    QObject* itemToDelete;
+
     void initGui();
     void deinitGui();
     void reposition(const QSize &sz, int rows);
@@ -65,6 +67,8 @@ protected slots:
     void onBtnGoClick();
     void onDeselect();
     void onReturnPressed();
+    void onFileDelete(const QString& filename);
+    void onDeletePendingItem();
 };
 
 #endif // SEARCHWINDOW_H
