@@ -349,22 +349,27 @@
         <translation>Добавить этот файл в очередь</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="864"/>
+        <location filename="../src/mainwindow.cpp" line="159"/>
+        <source>Delete this file</source>
+        <translation>Удалить этот файл</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="846"/>
         <source>Cache has been cleared</source>
         <translation>Кэш очищен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="918"/>
+        <location filename="../src/mainwindow.cpp" line="900"/>
         <source>Equalizer module not found!</source>
         <translation>Модуль эквалайзера не найден!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="935"/>
+        <location filename="../src/mainwindow.cpp" line="917"/>
         <source>The timer has been started</source>
         <translation>Таймер запущен</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="983"/>
+        <location filename="../src/mainwindow.cpp" line="965"/>
         <source>added %n more file(s)</source>
         <translation>
             <numerusform>добавлен ещё %n файл</numerusform>
@@ -373,58 +378,83 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="981"/>
+        <location filename="../src/mainwindow.cpp" line="1009"/>
+        <source>Delete the file?</source>
+        <translation>Удалить файл?</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="963"/>
         <source>total files count</source>
         <translation>общее число файлов</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="985"/>
+        <location filename="../src/mainwindow.cpp" line="967"/>
         <source>no new files added</source>
         <translation>новых файлов не добавлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1000"/>
+        <location filename="../src/mainwindow.cpp" line="982"/>
         <source>this file will be played next</source>
         <translation>этот файл будет проигран следующим</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1009"/>
+        <location filename="../src/mainwindow.cpp" line="991"/>
         <source>files queued</source>
         <translation>файлов в очереди</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1010"/>
+        <location filename="../src/mainwindow.cpp" line="992"/>
         <source>this file has been added to queue</source>
         <translation>этот файл был добавлен в очередь</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1185"/>
+        <location filename="../src/mainwindow.cpp" line="1004"/>
+        <source>filename</source>
+        <translation>имя файла</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1005"/>
+        <source>location</source>
+        <translation>расположение</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1025"/>
+        <source>Cannot delete the file</source>
+        <translation>Нельзя удалить файл</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1029"/>
+        <source>The file has been deleted</source>
+        <translation>Файл был удалён</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1227"/>
         <source>off</source>
         <comment>eqActionLabel</comment>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1188"/>
+        <location filename="../src/mainwindow.cpp" line="1230"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1279"/>
+        <location filename="../src/mainwindow.cpp" line="1324"/>
         <source>Playback has been stopped</source>
         <translation>Воспроизведение остановлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1336"/>
+        <location filename="../src/mainwindow.cpp" line="1386"/>
         <source>Timer has been stopped</source>
         <translation>Таймер остановлен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1348"/>
+        <location filename="../src/mainwindow.cpp" line="1398"/>
         <source>Timer</source>
         <translation>Таймер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1352"/>
+        <location filename="../src/mainwindow.cpp" line="1402"/>
         <source>off</source>
         <translation>выкл.</translation>
     </message>
@@ -434,13 +464,13 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="956"/>
-        <location filename="../src/mainwindow.cpp" line="972"/>
+        <location filename="../src/mainwindow.cpp" line="938"/>
+        <location filename="../src/mainwindow.cpp" line="954"/>
         <source>searching...</source>
         <translation>ищем...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="961"/>
+        <location filename="../src/mainwindow.cpp" line="943"/>
         <source>found %n file(s)</source>
         <translation>
             <numerusform>нашёлся %n файл</numerusform>
@@ -606,22 +636,22 @@
 <context>
     <name>SearchWindow</name>
     <message>
-        <location filename="../src/searchwindow.cpp" line="67"/>
+        <location filename="../src/searchwindow.cpp" line="70"/>
         <source>Search for files and folders</source>
         <translation>Искать файлы и папки</translation>
     </message>
     <message>
-        <location filename="../src/searchwindow.cpp" line="77"/>
+        <location filename="../src/searchwindow.cpp" line="80"/>
         <source>nothing&apos;s found</source>
         <translation>ничего не найдено</translation>
     </message>
     <message>
-        <location filename="../src/searchwindow.cpp" line="159"/>
+        <location filename="../src/searchwindow.cpp" line="177"/>
         <source>search</source>
         <translation>поиск</translation>
     </message>
     <message>
-        <location filename="../src/searchwindow.cpp" line="201"/>
+        <location filename="../src/searchwindow.cpp" line="218"/>
         <source>stop</source>
         <translation>стоп</translation>
     </message>
